Gammapy
=======

A Python Package for Gamma-ray Astronomy

* Webpage: https://gammapy.org
* Documentation: https://docs.gammapy.org/
* Code: https://github.com/gammapy/gammapy
* License: BSD-3

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org/

.. image:: http://mybinder.org/badge.svg
    :target: https://mybinder.org/v2/gh/gammapy/gammapy-webpage/master?urlpath=lab/tree/overview.ipynb

Status shields
++++++++++++++

(mostly useful for developers)

* .. image:: https://dev.azure.com/gammapy/gammapy/_apis/build/status/gammapy.gammapy
    :target: https://dev.azure.com/gammapy/gammapy/_build/latest?definitionId=1
    :alt: Build Status

* .. image:: http://img.shields.io/travis/gammapy/gammapy.svg?branch=master
    :target: https://travis-ci.org/gammapy/gammapy
    :alt: Test Status Travis-CI

* .. image:: https://codecov.io/gh/gammapy/gammapy/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/gammapy/gammapy

* .. image:: https://img.shields.io/lgtm/alerts/g/gammapy/gammapy.svg?logo=lgtm&logoWidth=18
    :target: https://lgtm.com/projects/g/gammapy/gammapy/alerts/
    :alt: LGTM

* .. image:: https://api.codacy.com/project/badge/Grade/32cac57dfd9a4d4cb96e7563d5350298
    :target: https://www.codacy.com/app/cdeil/gammapy?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=gammapy/gammapy&amp;utm_campaign=Badge_Grade
    :alt: Codacy

* .. image:: http://img.shields.io/pypi/v/gammapy.svg?text=version
    :target: https://pypi.org/project/gammapy/
    :alt: Latest release

* https://www.openhub.net/p/gammapy
